* {
    margin: 0;
    padding: 0;
    box-sizing: border-box;
}

body {
    font-family: var(--font-family);
    font-size: var(--font-size-md);
    color: var(--text-primary);
    background-color: var(--primary-bg);
    height: 100vh;
    display: flex;
    align-items: center;
    justify-content: center;
}