.content-title {
    font-size: var(--font-size-lg);
    font-weight: 500;
    margin-bottom: var(--spacing-md);
    color: var(--text-primary);
}

.content-text {
    color: var(--text-secondary);
    line-height: 1.5;
    margin-bottom: var(--spacing-md);
}

.text-left { text-align: left; }
.text-center { text-align: center; }
.text-right { text-align: right; }