.dashboard {
    display: flex;
    width: var(--dashboard-width);
    height: var(--dashboard-height);
    background-color: var(--dashboard-bg);
    border: 1px solid var(--outline-color);
    border-radius: var(--border-radius);
}

.sidebar {
    width: var(--sidebar-width);
    background-color: var(--sidebar-bg);
    color: var(--text-primary);
    padding: var(--spacing-lg);
    border-right: 1px solid var(--outline-color);
    border-radius: var(--border-radius) 0 0 var(--border-radius);
}

.content {
    width: var(--content-width);
    background-color: var(--content-bg);
    padding: var(--spacing-xl);
    border-radius: 0 var(--border-radius) var(--border-radius) 0;
}

.content-section {
    margin-bottom: var(--spacing-xl);
    padding: var(--spacing-lg);
    border: 1px solid var(--outline-color);
    border-radius: var(--border-radius);
}

.card {
    background-color: var(--content-bg);
    border: 1px solid var(--outline-color);
    border-radius: var(--border-radius);
    padding: var(--spacing-lg);
    margin-bottom: var(--spacing-md);
}

.grid-container {
    border: 1px solid var(--outline-color);
    border-radius: var(--border-radius);
    overflow: hidden;
    margin-bottom: var(--spacing-md);
}