.menu-item {
    padding: var(--spacing-md);
    margin-bottom: var(--spacing-md);
    border-radius: var(--border-radius);
    cursor: pointer;
    border: 1px solid transparent;
    transition: border-color 0.2s ease;
}

.menu-item:hover {
    border-color: var(--outline-color);
}

.menu-item.active {
    border-color: var(--outline-color);
    background-color: rgba(255, 255, 255, 0.05);
}
